==> vulkan4j-0.1.0-sources.jar: tech/icey/vk4j/datatype/VkSurfaceCapabilitiesPresentBarrierNV.java <==
package tech.icey.vk4j.datatype;

import java.lang.foreign.*;
import static java.lang.foreign.ValueLayout.*;

import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.*;
import tech.icey.panama.buffer.*;
import tech.icey.vk4j.bitmask.*;
import tech.icey.vk4j.datatype.*;
import tech.icey.vk4j.enumtype.*;
import tech.icey.vk4j.handle.*;
import static tech.icey.vk4j.Constants.*;
import static tech.icey.vk4j.enumtype.VkStructureType.*;

/// {@snippet lang=c :
/// typedef struct VkSurfaceCapabilitiesPresentBarrierNV {
///     VkStructureType sType;
///     void* pNext;
///     VkBool32 presentBarrierSupported;
/// } VkSurfaceCapabilitiesPresentBarrierNV;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkSurfaceCapabilitiesPresentBarrierNV.html">VkSurfaceCapabilitiesPresentBarrierNV</a>
public record VkSurfaceCapabilitiesPresentBarrierNV(MemorySegment segment) implements IPointer {
    public VkSurfaceCapabilitiesPresentBarrierNV(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_SURFACE_CAPABILITIES_PRESENT_BARRIER_NV);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public @unsigned int presentBarrierSupported() {
        return segment.get(LAYOUT$presentBarrierSupported, OFFSET$presentBarrierSupported);
    }

    public void presentBarrierSupported(@unsigned int value) {
        segment.set(LAYOUT$presentBarrierSupported, OFFSET$presentBarrierSupported, value);
    }

    public static VkSurfaceCapabilitiesPresentBarrierNV allocate(Arena arena) {
        return new VkSurfaceCapabilitiesPresentBarrierNV(arena.allocate(LAYOUT));
    }

    public static VkSurfaceCapabilitiesPresentBarrierNV[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkSurfaceCapabilitiesPresentBarrierNV[] ret = new VkSurfaceCapabilitiesPresentBarrierNV[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkSurfaceCapabilitiesPresentBarrierNV(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkSurfaceCapabilitiesPresentBarrierNV clone(Arena arena, VkSurfaceCapabilitiesPresentBarrierNV src) {
        VkSurfaceCapabilitiesPresentBarrierNV ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkSurfaceCapabilitiesPresentBarrierNV[] clone(Arena arena, VkSurfaceCapabilitiesPresentBarrierNV[] src) {
        VkSurfaceCapabilitiesPresentBarrierNV[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        ValueLayout.JAVA_INT.withName("presentBarrierSupported")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$presentBarrierSupported = PathElement.groupElement("presentBarrierSupported");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final OfInt LAYOUT$presentBarrierSupported = (OfInt) LAYOUT.select(PATH$presentBarrierSupported);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$presentBarrierSupported = LAYOUT.byteOffset(PATH$presentBarrierSupported);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$presentBarrierSupported = LAYOUT$presentBarrierSupported.byteSize();
}

==> vulkan4j-0.2.1-sources.jar: tech/icey/vk4j/datatype/VkSurfaceCapabilitiesPresentBarrierNV.java <==
package tech.icey.vk4j.datatype;

import java.lang.foreign.*;
import static java.lang.foreign.ValueLayout.*;

import org.jetbrains.annotations.Nullable;
import tech.icey.panama.IPointer;
import tech.icey.panama.NativeLayout;
import tech.icey.panama.annotation.*;
import tech.icey.panama.buffer.*;
import tech.icey.vk4j.bitmask.*;
import tech.icey.vk4j.datatype.*;
import tech.icey.vk4j.enumtype.*;
import tech.icey.vk4j.handle.*;
import static tech.icey.vk4j.Constants.*;
import static tech.icey.vk4j.enumtype.VkStructureType.*;

/// {@snippet lang=c :
/// typedef struct VkSurfaceCapabilitiesPresentBarrierNV {
///     VkStructureType sType;
///     void* pNext;
///     VkBool32 presentBarrierSupported;
/// } VkSurfaceCapabilitiesPresentBarrierNV;}
///
/// @see <a href="https://registry.khronos.org/vulkan/specs/1.3-extensions/man/html/VkSurfaceCapabilitiesPresentBarrierNV.html">VkSurfaceCapabilitiesPresentBarrierNV</a>
public record VkSurfaceCapabilitiesPresentBarrierNV(MemorySegment segment) implements IPointer {
    public VkSurfaceCapabilitiesPresentBarrierNV(MemorySegment segment) {
        this.segment = segment;
        this.sType(VK_STRUCTURE_TYPE_SURFACE_CAPABILITIES_PRESENT_BARRIER_NV);
    }

    public @enumtype(VkStructureType.class) int sType() {
        return segment.get(LAYOUT$sType, OFFSET$sType);
    }

    public void sType(@enumtype(VkStructureType.class) int value) {
        segment.set(LAYOUT$sType, OFFSET$sType, value);
    }

    public @pointer(comment="void*") MemorySegment pNext() {
        return segment.get(LAYOUT$pNext, OFFSET$pNext);
    }

    public void pNext(@pointer(comment="void*") MemorySegment value) {
        segment.set(LAYOUT$pNext, OFFSET$pNext, value);
    }

    public void pNext(@Nullable IPointer pointer) {
        pNext(pointer == null ? MemorySegment.NULL : pointer.segment());
    }

    public @unsigned int presentBarrierSupported() {
        return segment.get(LAYOUT$presentBarrierSupported, OFFSET$presentBarrierSupported);
    }

    public void presentBarrierSupported(@unsigned int value) {
        segment.set(LAYOUT$presentBarrierSupported, OFFSET$presentBarrierSupported, value);
    }

    public static VkSurfaceCapabilitiesPresentBarrierNV allocate(Arena arena) {
        return new VkSurfaceCapabilitiesPresentBarrierNV(arena.allocate(LAYOUT));
    }

    public static VkSurfaceCapabilitiesPresentBarrierNV[] allocate(Arena arena, int count) {
        MemorySegment segment = arena.allocate(LAYOUT, count);
        VkSurfaceCapabilitiesPresentBarrierNV[] ret = new VkSurfaceCapabilitiesPresentBarrierNV[count];
        for (int i = 0; i < count; i++) {
            ret[i] = new VkSurfaceCapabilitiesPresentBarrierNV(segment.asSlice(i * SIZE, SIZE));
        }
        return ret;
    }

    public static VkSurfaceCapabilitiesPresentBarrierNV clone(Arena arena, VkSurfaceCapabilitiesPresentBarrierNV src) {
        VkSurfaceCapabilitiesPresentBarrierNV ret = allocate(arena);
        ret.segment.copyFrom(src.segment);
        return ret;
    }

    public static VkSurfaceCapabilitiesPresentBarrierNV[] clone(Arena arena, VkSurfaceCapabilitiesPresentBarrierNV[] src) {
        VkSurfaceCapabilitiesPresentBarrierNV[] ret = allocate(arena, src.length);
        for (int i = 0; i < src.length; i++) {
            ret[i].segment.copyFrom(src[i].segment);
        }
        return ret;
    }

    public static final MemoryLayout LAYOUT = NativeLayout.structLayout(
        ValueLayout.JAVA_INT.withName("sType"),
        ValueLayout.ADDRESS.withName("pNext"),
        ValueLayout.JAVA_INT.withName("presentBarrierSupported")
    );
    public static final long SIZE = LAYOUT.byteSize();

    public static final PathElement PATH$sType = PathElement.groupElement("sType");
    public static final PathElement PATH$pNext = PathElement.groupElement("pNext");
    public static final PathElement PATH$presentBarrierSupported = PathElement.groupElement("presentBarrierSupported");

    public static final OfInt LAYOUT$sType = (OfInt) LAYOUT.select(PATH$sType);
    public static final AddressLayout LAYOUT$pNext = (AddressLayout) LAYOUT.select(PATH$pNext);
    public static final OfInt LAYOUT$presentBarrierSupported = (OfInt) LAYOUT.select(PATH$presentBarrierSupported);

    public static final long OFFSET$sType = LAYOUT.byteOffset(PATH$sType);
    public static final long OFFSET$pNext = LAYOUT.byteOffset(PATH$pNext);
    public static final long OFFSET$presentBarrierSupported = LAYOUT.byteOffset(PATH$presentBarrierSupported);

    public static final long SIZE$sType = LAYOUT$sType.byteSize();
    public static final long SIZE$pNext = LAYOUT$pNext.byteSize();
    public static final long SIZE$presentBarrierSupported = LAYOUT$presentBarrierSupported.byteSize();
}
